@@ -263,6 +263,7 @@ read_harddisk_serial(char *device, char *serial) {
 	}
 }
 
+#if defined(__x86_64__) || defined(__i386__)
 static bool
 is_virtualized() {
 	unsigned int eax, ebx, ecx, edx;
@@ -305,6 +306,22 @@ hypervisor_port(unsigned int cmd, unsigned int *eax, unsigned int *ebx,
 		: "memory"
 	);
 }
+#else
+static bool
+is_virtualized() {
+	/*
+		Always return false, because other architectures
+		do not support the virtualization bit.
+	*/
+	return false;
+}
+
+void
+hypervisor_port(unsigned int cmd, unsigned int *eax, unsigned int *ebx,
+		unsigned int *ecx, unsigned int *edx)
+{
+}
+#endif
 
 int
 hypervisor_port_check(void) {
